<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="AddAttribute">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                     style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
        <el-button style="margin-left: 10px" icon="el-icon-sort" @click="savePropertyf">保存排序号</el-button>
      </div>
      <el-table border size="mini" :data="AttributeTableData" :height="tableMaxHeight" :style="{width: '100%'}"
                :cell-style="{'text-align': 'center'}" :header-cell-style="{'text-align': 'center'}"
                @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column  prop="code" label="属性标识"></el-table-column>
        <el-table-column  prop="name" label="属性名称"></el-table-column>
        <el-table-column  prop="typeName" label="属性类型"></el-table-column>
        <el-table-column  prop="dataUnitNane" label="数据单位"></el-table-column>
        <!-- <el-table-column
        
        prop="dataDataFormartName"
        label="数据格式化"
      ></el-table-column> -->
        <el-table-column  prop="isReadonly" label="是否只读">
          <template slot-scope="scope">
            <div>
              {{ scope.row.isReadonly == 1 ? '是' : '否' }}
            </div>
          </template>
        </el-table-column>
        <el-table-column prop="memo" label="备注"></el-table-column>
        <el-table-column  prop="sn" label="排序" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-input type="number" size="small" min="1" @input="insort(scope.row)" v-model="scope.row.sn">
            </el-input>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background ref="paginationPanel" @size-change="handleSizeChange"
                     @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
                     :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <!-- 属性弹窗 -->
    <attributeDialog ref="attributemodel" @loadData="loadData" :parameterID="parameterID" :pId="pId">
    </attributeDialog>
  </div>
</template>
<script>
import PhysicalModel from '@/api/device/PhysicalModel.js'
import attributeDialog from '@/views/Device/deviceManage/components/modle/attributeDialog'
import {
  TableMixin
} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'AttrbuteDefinition',
  props: {
    parameterData: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  components: {
    attributeDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/device/metadata/properties/'
      },
      pId: '',
      activeName: 'first',
      AttributeTableData: [],
      parameterID: {},
      dataTypes: [],
      dataUnits: [],
      sortList: {}
    }
  },
  created() {
    this.parameterID = this.parameterData
    // 数据单位
    this.dataUnits = dictUtils.getDictItemsFromCache('sjdw')
    // 属性类型
    this.dataTypes = dictUtils.getDictItemsFromCache('sxlx')
  },
  methods: {
    // 新增
    AddAttribute() {
      this.$refs.attributemodel.addShow()
    },
    // 修改
    handleUpdate(row) {
      // console.log(row.id)
      this.$refs.attributemodel.Update(row)
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.queryParam.querys = [{
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'productId',
        relation: 'AND',
        value: this.parameterData.id
      }]
      this.queryParam.sorter = [{
        direction: 'ASC',
        property: 'sn'
      }]
      this.AttributeTableData = []
      PhysicalModel.attributeList(this.queryParam, res => {
        // console.log(res, 'res')
        this.total = res.total
        res.rows.sort((a, b) => {
          return a.sn - b.sn
        })
        this.AttributeTableData = res.rows
        this.AttributeTableData.forEach(e => {
          this.dataTypes.forEach(t => {
            if (t.value == e.dataType) {
              e.typeName = t.name
            }
          })
          if (!!e.dataUnit) {
            this.dataUnits.forEach(x => {
              if (x.value == e.dataUnit) {
                e.dataUnitNane = x.name
              }
            })
          }
        })
        this.$set(this.AttributeTableData)
      })
    },
    savePropertyf() {
      PhysicalModel.saveAttributeProperty(this.sortList, res => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: res.message,
            duration: 2000
          })
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    insort(val) {
      let id = val.id
      let value = val.sn
      this.sortList[id] = value
    }
  }
}
</script>
<style lang="scss" scoped>
::v-deep .el-table {
  height: 100% !important;
}

.bbsl-common-page {
  height: calc(100% - 10px);
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}
</style>
